#
# The command line interface, obviously ;-)
#
# Fair warning that the CLI interface will almost certainly change drastically
# at some point in the not too distant future.  I've used GLI because frankly
# it's the quickest thing to prototype with, but I don't intend to keep it
# because I find the interface it generates to be unintuitive and often a tad
# frustrating.
#

require 'gli'
require 'confer'

include GLI::App

program_desc      'Lightweight configuration management'
program_long_desc 'Inspired by tools such as Ansible, Puppet and Chef, but at a much smaller scale if you only have a server or two to manage.'
version           Confer::VERSION

flag 'host',      'h', default_value: 'default',       desc: 'Specify the host to configure'
flag 'inventory', 'i', default_value: 'inventory.yml', desc: 'Specify the inventory to use'
flag 'recipe',    'r', default_value: 'recipe.yml',    desc: 'Specify the recipe to use'

inventory = nil
recipe    = nil
host      = nil

pre do |global, command, opts, args|
  inventory = Confer::Inventory.from_file global[:inventory]
  recipe    = Confer::Recipe.from_file    global[:recipe]
  host      = inventory.hosts[global[:host]]

  true
end

on_error do |e|
  $stdout.puts "#{e.class.name}: #{e.message}"
  $stdout.puts e.backtrace.join "\n"
  false
end

desc 'Queries configurator values'
command :query do |c|
  c.flag 'configurator', '-c', desc: 'The configurator to query'

  c.action do |global, opts, args|
    Confer::Connection.start(host.options['connection']) do |connection|
      recipe.steps.each do |step|
        $stdout.puts "===== #{step.configurator} => #{step.options}"
        configurator = Confer::Configurator.get(step.configurator, step.options)
        puts configurator.query(connection)
        $stdout.puts
      end
    end
  end
end

desc 'Verifies the recipe against configurator values'
command :verify do |c|
  c.action do |global, opts, args|

  end
end

desc 'Applies the recipe to the remote host'
command :apply do |c|
  c.action do |global, opts, args|

  end
end

exit run ARGV
