require 'diffy'

module Confer
  module Configurators

    #
    # Public: Configures the timezone on the remote host.
    #
    # Attributes
    #
    # timezone - The desired time zone in the format expected by the file
    #            `/etc/timezone` on a Linux machine.  E.g. London, UK would
    #            be `Europe/London`.
    #
    class Tzdata < Configurator

      #
      # Public: The desired time zone.
      #
      attr_accessor :timezone

      #
      # See `Confer::Configurator#query`
      #
      def query(connection)
        connection.exec! 'cat /etc/timezone'
      end

      #
      # See `Confer::Configurator#verify`
      #
      def verify(connection)
        expected = query.strip
        return true if expected == timezone
        Diffy::Diff.new(expected, timezone).to_s(:color)
      end

      #
      # See `Confer::Configurator#apply`
      #
      def apply(connection)
        # sh "echo '#{params[:timezone]}' > /etc/timezone"
        # sh "dpkg-reconfigure -f noninteractive tzdata"
      end

    end

  end
end
